#!/usr/bin/env bash
#
# Waits until cert-manager HelmRelease is ready, and then installs a ZeroSSL
# ClusterIssuer with our credentials into the cert-manager namespace
#
# Usage:
#
#   ./install_zerossl_issuer.sh
set -euo pipefail

# Create secret with HMAC key
kubectl -n cert-manager create secret generic zerossl-eabsecret --from-literal "secret=${ZEROSSL_EAB_HMAC_KEY}"

# Wait until cert-manager is ready
"$(dirname "$0")/retry_cmd_until_success.sh" 30 10 "flux get helmrelease -n cert-manager --status-selector ready=true --no-header | grep cert-manager"

# Add ZeroSSL ClusterIssuer
kubectl apply -n cert-manager -f - <<EOF
---
apiVersion: cert-manager.io/v1
kind: ClusterIssuer
metadata:
  name: zerossl-issuer
spec:
  acme:
    # The ACME server URL
    server: https://acme.zerossl.com/v2/DV90
    externalAccountBinding:
      keyID: ${ZEROSSL_EAB_KID}
      keySecretRef:
        name: zerossl-eabsecret
        key: secret
      keyAlgorithm: HS256
    # Name of a secret used to store the ACME account private key
    privateKeySecretRef:
      name: zerossl-prod
    solvers:
      - http01:
          ingress:
            class: nginx
EOF
